summaryrefslogtreecommitdiff
path: root/tests/test-modules.c
diff options
context:
space:
mode:
authorStef Walter <stefw@gnome.org>2012-07-17 08:08:04 +0200
committerStef Walter <stefw@gnome.org>2012-07-26 12:22:31 +0200
commit542cb48951b7c4c21ca3669d07bf936b0fa58b42 (patch)
tree44bfd4e76bd441d0695a1fbb0099f7d6d5dcafa3 /tests/test-modules.c
parent06595e93ff57e97adbb313aebc50a2e32acd6039 (diff)
Don't rely on loading order for duplicate modules
* We had relied on module 'two' loading before 'two-duplicate' in the conf tests. However this isn't always the case, and the name of the module can end up as 'two-duplicate' https://bugzilla.gnome.org/show_bug.cgi?id=44740
Diffstat (limited to 'tests/test-modules.c')
-rw-r--r--tests/test-modules.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/test-modules.c b/tests/test-modules.c
index f755298..74560d9 100644
--- a/tests/test-modules.c
+++ b/tests/test-modules.c
@@ -137,12 +137,12 @@ test_disable (CuTest *tc)
CK_FUNCTION_LIST_PTR_PTR modules;
/*
* The module two should be present, as we don't match any prognames
* that it has disabled.
*/
modules = initialize_and_get_modules (tc);
- CuAssertTrue (tc, lookup_module_with_name (tc, modules, "two.badname") != NULL);
+ CuAssertTrue (tc, lookup_module_with_name (tc, modules, "four") != NULL);
finalize_and_free_modules (tc, modules);
/*
@@ -155,7 +155,7 @@ test_disable (CuTest *tc)
p11_kit_set_progname ("test-disable");
modules = initialize_and_get_modules (tc);
- CuAssertTrue (tc, lookup_module_with_name (tc, modules, "two.badname") == NULL);
+ CuAssertTrue (tc, lookup_module_with_name (tc, modules, "four") == NULL);
finalize_and_free_modules (tc, modules);
p11_kit_set_progname (NULL);
@@ -137,12 +137,12 @@ test_disable (CuTest *tc)
CK_FUNCTION_LIST_PTR_PTR modules;
/*
- * The module two should be present, as we don't match any prognames
+ * The module four should be present, as we don't match any prognames
* that it has disabled.
*/